@@ -1,8 +1,10 @@
 from urllib3.util.retry import Retry
 from .discovery.auth.discovery import Discovery as AuthDiscovery
 from .discovery.automation.discovery import Discovery as AutomationDiscovery
-from .discovery.crm.discovery import Discovery as CrmDiscovery
 from .discovery.cms.discovery import Discovery as CmsDiscovery
+from .discovery.conversations.discovery import Discovery as ConversationsDiscovery
+from .discovery.crm.discovery import Discovery as CrmDiscovery
+from .discovery.events.discovery import Discovery as EventsDiscovery
 from .discovery.files.discovery import Discovery as FilesDiscovery
 from .discovery.marketing.discovery import Discovery as MarketingDiscovery
 from .discovery.webhooks.discovery import Discovery as WebhooksDiscovery
@@ -52,10 +54,18 @@ class Client:
     def cms(self):
         return CmsDiscovery(self.config)
 
+    @property
+    def conversations(self):
+        return ConversationsDiscovery(self.config)
+
     @property
     def crm(self):
         return CrmDiscovery(self.config)
 
+    @property
+    def events(self):
+        return EventsDiscovery(self.config)
+
     @property
     def files(self):
         return FilesDiscovery(self.config)
